if (GAZEBO_CONFIG_INCLUDED)
  return()
endif()
set(GAZEBO_CONFIG_INCLUDED TRUE)

list(APPEND GAZEBO_INCLUDE_DIRS /usr/include)
list(APPEND GAZEBO_INCLUDE_DIRS /usr/include/gazebo-5.0)

list(APPEND GAZEBO_LIBRARY_DIRS /usr/lib/x86_64-linux-gnu)
list(APPEND GAZEBO_LIBRARY_DIRS /usr/lib/x86_64-linux-gnu/gazebo-5.0/plugins)

list(APPEND GAZEBO_CFLAGS -I/usr/include)
list(APPEND GAZEBO_CFLAGS -I/usr/include/gazebo-5.0)

# Visual Studio enables c++11 support by default
if (NOT MSVC)
  list(APPEND GAZEBO_CXX_FLAGS -std=c++11)
endif()
if ("${CMAKE_CXX_COMPILER_ID}" MATCHES "Clang" AND
    "${CMAKE_SYSTEM_NAME}" MATCHES "Darwin")
  set(GAZEBO_CXX_FLAGS "${GAZEBO_CXX_FLAGS} -stdlib=libc++")
endif ()

foreach(lib gazebo;gazebo_common;gazebo_gimpact;gazebo_gui;gazebo_gui_building;gazebo_gui_viewers;gazebo_math;gazebo_msgs;gazebo_ode;gazebo_opcode;gazebo_opende_ou;gazebo_physics;gazebo_physics_ode;gazebo_rendering;gazebo_selection_buffer;gazebo_sensors;gazebo_skyx;gazebo_transport;gazebo_util;gazebo_ccd;gazebo_player;gazebo_rendering_deferred)
  set(onelib "${lib}-NOTFOUND")
  find_library(onelib ${lib}
    PATHS /usr/lib/x86_64-linux-gnu
    NO_DEFAULT_PATH
    )
  if(NOT onelib)
    message(FATAL_ERROR "Library '${lib}' in package GAZEBO is not installed properly")
  endif()
  list(APPEND GAZEBO_LIBRARIES ${onelib})
endforeach()

# Get the install prefix for OGRE
execute_process(COMMAND pkg-config --variable=prefix OGRE
  OUTPUT_VARIABLE OGRE_INSTALL_PREFIX OUTPUT_STRIP_TRAILING_WHITESPACE)

# Add the OGRE cmake path to CMAKE_MODULE_PATH
set(CMAKE_MODULE_PATH
  "${OGRE_INSTALL_PREFIX}/share/OGRE/cmake/modules;${OGRE_INSTALL_PREFIX}/CMake;${CMAKE_MODULE_PATH}")

foreach(dep Boost;Protobuf;SDFormat;OGRE)
  if(NOT ${dep}_FOUND)
    find_package(${dep} REQUIRED)
  endif()
  list(APPEND GAZEBO_INCLUDE_DIRS ${${dep}_INCLUDE_DIRS})

  # Protobuf needs to be capitalized to match PROTOBUF_LIBRARIES
  if (${dep} STREQUAL "Protobuf")
    string (TOUPPER ${dep} dep_lib)
  else()
    set (dep_lib ${dep})
  endif()

  list(APPEND GAZEBO_LIBRARIES ${${dep_lib}_LIBRARIES})

  # When including OGRE, also include the Terrain and Paging components
  if (${dep} STREQUAL "OGRE")
    list(APPEND GAZEBO_INCLUDE_DIRS ${OGRE_Terrain_INCLUDE_DIRS}
      ${OGRE_Paging_INCLUDE_DIRS})
    list(APPEND GAZEBO_LIBRARIES ${OGRE_Terrain_LIBRARIES}
      ${OGRE_Paging_LIBRARIES})
  endif()

endforeach()

list(APPEND GAZEBO_LDFLAGS -Wl,-rpath,/usr/lib/x86_64-linux-gnu/gazebo-5.0/plugins)
list(APPEND GAZEBO_LDFLAGS -L/usr/lib/x86_64-linux-gnu)
list(APPEND GAZEBO_LDFLAGS -L/usr/lib/x86_64-linux-gnu/gazebo-5.0/plugins)
